<?php

namespace Drupal\sibs_api\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure sibs_api settings for this site.
 */
class SibsSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sibs_api_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['sibs_api.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('sibs_api.settings');
    $form['client_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client-Id'),
      '#default_value' => $config->get('client_id'),
      '#required' => TRUE,
    ];

    $form['terminal_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Terminal ID'),
      '#default_value' => $config->get('terminal_id'),
      '#required' => TRUE,
    ];

    $form['token'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Token'),
      '#default_value' => $config->get('token'),
      '#required' => TRUE,
    ];

    $form['entity'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Payment Service Entity'),
      '#default_value' => $config->get('entity'),
      '#required' => TRUE,
    ];

    $form['webhook_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Webhook Secret'),
      '#default_value' => $config->get('webhook_secret'),
      '#required' => TRUE,
    ];

    $form['endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Integration Endpoint'),
      '#default_value' => $config->get('endpoint'),
      '#required' => TRUE,
    ];

    $form['spg'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('SPG'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];

    $form['spg']['spg_return_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Return URL'),
      '#default_value' => $config->get('spg_return_url'),
      '#required' => TRUE,
    ];
    $form['spg']['spg_validity'] = [
      '#type' => 'number',
      '#attributes' => [
        'min' => 0,
      ],
      '#title' => $this->t('Validity'),
      '#default_value' => $config->get('spg_validity'),
      '#description' => $this->t('Number of days the payment is valid'),
      '#required' => TRUE,
    ];

    $form['mb'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('MB'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];
    $form['mb']['mb_validity'] = [
      '#type' => 'number',
      '#attributes' => [
        'min' => 0,
      ],
      '#title' => $this->t('Validity'),
      '#default_value' => $config->get('mb_validity'),
      '#description' => $this->t('Number of days the payment is valid'),
      '#required' => TRUE,
    ];

    $form['mbway'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('MB Way'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];
    $form['mbway']['mbway_validity'] = [
      '#type' => 'number',
      '#attributes' => [
        'min' => 0,
      ],
      '#title' => $this->t('Validity'),
      '#default_value' => $config->get('mbway_validity'),
      '#description' => $this->t('Number of days the payment is valid'),
      '#required' => TRUE,
    ];

    $form['errors'] = [
      '#type' => 'select',
      '#title' => $this->t('Error handling'),
      '#default_value' => $config->get('errors'),
      '#options' => [
        'none' => $this->t("None"),
        'log' => $this->t("Database logging"),
        'screen' => $this->t("Output in page"),
        'both' => $this->t("Both"),
      ],
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('sibs_api.settings')
      ->set('client_id', $form_state->getValue('client_id'))
      ->set('terminal_id', $form_state->getValue('terminal_id'))
      ->set('entity', $form_state->getValue('entity'))
      ->set('token', $form_state->getValue('token'))
      ->set('endpoint', $form_state->getValue('endpoint'))
      ->set('webhook_secret', $form_state->getValue('webhook_secret'))
      ->set('spg_return_url', $form_state->getValue('spg_return_url'))
      ->set('spg_validity', $form_state->getValue('spg_validity'))
      ->set('mb_validity', $form_state->getValue('mb_validity'))
      ->set('mbway_validity', $form_state->getValue('mbway_validity'))
      ->set('errors', $form_state->getValue('errors'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
